Struct futures_lite::io::AssertAsync [−][src]
pub struct AssertAsync<T>(_);Expand description
Asserts that a type implementing std::io traits can be used as an async type.
The underlying I/O handle should never block nor return the ErrorKind::WouldBlock error.
This is usually the case for in-memory buffered I/O.
Examples
use futures_lite::io::{AssertAsync, AsyncReadExt};
let reader: &[u8] = b"hello";
let mut async_reader = AssertAsync::new(reader);
let mut contents = String::new();
// This line works in async manner - note that there is await:
async_reader.read_to_string(&mut contents).await?;Implementations
Gets a reference to the inner I/O handle.
Examples
use futures_lite::io::AssertAsync;
let reader: &[u8] = b"hello";
let async_reader = AssertAsync::new(reader);
let r = async_reader.get_ref();Gets a mutable reference to the inner I/O handle.
Examples
use futures_lite::io::AssertAsync;
let reader: &[u8] = b"hello";
let mut async_reader = AssertAsync::new(reader);
let r = async_reader.get_mut();Extracts the inner I/O handle.
Examples
use futures_lite::io::AssertAsync;
let reader: &[u8] = b"hello";
let async_reader = AssertAsync::new(reader);
let inner = async_reader.into_inner();Trait Implementations
Attempt to read from the AsyncRead into buf. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more